{% extends "one_column_body.html" %} {% block content %}

# Colors

## Neutral

--clr-neutral-10
--clr-neutral-20
--clr-neutral-35
--clr-neutral-50
--clr-neutral-60
--clr-neutral-65
--clr-neutral-80
--clr-neutral-90

## Reds

--clr-danger-dark
--clr-danger
--clr-danger-pale

## Yellows

--clr-highlight-pale-95
--clr-highlight-pale-90
--clr-highlight-pale-80
--clr-highlight-pale-75
--clr-highlight-pale
--clr-highlight-90
--clr-highlight-70

## Blues

--clr-blue-pale
--clr-blue-65
--clr-blue-60
--clr-blue-50
--clr-blue-45
--clr-blue-40
--clr-blue-30

## Greens

--clr-green-65
--clr-green-60
--clr-green-50
--clr-green-45
--clr-green-40
--clr-green-30

## Special Colors

--gold-badge-color
--bronze-badge-color
--rss-link-color
--or-4
answ. count
{% endblock %}